pywr.parameters.control_curves.BaseControlCurveParameter — Pywr 0.5dev documentation

# pywr.parameters.control_curves.BaseControlCurveParameter

class `pywr.parameters.control_curves.` `BaseControlCurveParameter`

  Base class for all Parameters that rely on a the attached Node containing a control_curve Parameter

  `__init__`()

    Parameters: | storage_node : Storage An optional Storage node that can be used to query the current percentage volume. control_curves : iterable of Parameter objects or single Parameter The Parameter objects to use as a control curve(s).

  Methods

  `after` |
  `before` |
  `finish` |
  `get_all_values` |
  `get_double_lower_bounds` |
  `get_double_upper_bounds` |
  `get_double_variables` |
  `get_integer_lower_bounds` |
  `get_integer_upper_bounds` |
  `get_integer_variables` |
  `get_value` |
  `load` |
  `lower_bounds` |
  `register` |
  `reset` |
  `set_double_variables` |
  `set_integer_variables` |
  `setup` |
  `unregister` |
  `update` |
  `upper_bounds` |
  `value` |

  Attributes

  `children` |
  `comment` |
  `control_curves` |
  `double_size` |
  `integer_size` |
  `is_variable` |
  `model` |
  `name` |
  `parents` |
  `size` |
  `storage_node` |